;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "linkin-org" "20251116.1638"
  "A workflow with fast, reliable links."
  '((emacs "30.1"))
  :url "https://github.com/Judafa/linkin-org"
  :commit "1ce63411cc48a89a5b430516f7670f8af208047d"
  :revdesc "1ce63411cc48"
  :authors '(("Julien Dallot" . "judafa@protonmail.com"))
  :maintainers '(("Julien Dallot" . "judafa@protonmail.com")))
